@@ -21,7 +21,7 @@
 # Module Header
 # Filename          : IP.pm
 # Purpose           : Provide functions to manipulate IPv4/v6 addresses
-# Author            : Manuel Valente <manuel@ripe.net>
+# Author            : Manuel Valente <mvalente@idealx.com>
 # Date              : 19991124
 # Description       : 
 # Language Version  : Perl 5
@@ -48,7 +48,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $ERROR $ERRNO
 	%IPv4ranges %IPv6ranges $useBigInt
 	$IP_NO_OVERLAP $IP_PARTIAL_OVERLAP $IP_A_IN_B_OVERLAP $IP_B_IN_A_OVERLAP $IP_IDENTICAL);
 
-$VERSION = '1.20';
+$VERSION = '1.21';
 
 require Exporter;
 
@@ -2616,7 +2616,7 @@ Math::BigInt will become optionnal.
 
 =head1 AUTHORS
 
-Manuel Valente <mvalente@ripe.net>.
+Manuel Valente <mvalente@idealx.com>.
 
 Original IPv4 code by Monica Cortes Sack <mcortes@ripe.net>.
 
